@@ -60,11 +60,12 @@ class Decoder:
             result += "TAF for "
 
         # Add ordinal suffix
-        suffix = self._get_ordinal_suffix(_header["origin_date"])
-        _header["origin_date"] = _header["origin_date"] + suffix
+        _header["origin_date"] = _header["origin_date"] + self._get_ordinal_suffix(_header["origin_date"])
+        _header["valid_from_date"] = _header["valid_from_date"] + self._get_ordinal_suffix(_header["valid_from_date"]) 
+        _header["valid_till_date" ] = _header["valid_till_date"] + self._get_ordinal_suffix(_header["valid_till_date"])
 
         result += ("%(icao_code)s issued %(origin_hours)s:%(origin_minutes)s UTC on the %(origin_date)s, " 
-                   "valid from %(valid_from_date)s %(valid_from_hours)s:00 UTC to %(valid_till_date)s %(valid_till_hours)s:00 UTC")
+                   "valid from %(valid_from_hours)s:00 UTC on the %(valid_from_date)s to %(valid_till_hours)s:00 UTC on the %(valid_till_date)s")
 
         result = result % _header
 
@@ -98,12 +99,12 @@ class Decoder:
                                        "from_hours":  _header["from_hours"],
                                        "till_date":   _header["till_date"],
                                        "till_hours":  _header["till_hours"] }
-            elif header["type"] == "TEMPO":
+            elif _header["type"] == "TEMPO":
                 result += tempo_str % { "from_date":  _header["from_date"], 
                                         "from_hours": _header["from_hours"], 
                                         "till_date":  _header["till_date"], 
                                         "till_hours": _header["till_hours"] }
-            elif header["type"] == "BECMG":
+            elif _header["type"] == "BECMG":
                 result += becmg_str % { "from_date":  _header["from_date"], 
                                         "from_hours": _header["from_hours"], 
                                         "till_date":  _header["till_date"],
@@ -283,11 +284,11 @@ class Decoder:
 
         if re.match(".*(1[12]|[04-9])$", _date):
             suffix = "th"
-        elif re.match(".*1", _date):
+        elif re.match(".*1$", _date):
             suffix = "st"
-        elif re.match(".*2", _date):
+        elif re.match(".*2$", _date):
             suffix = "nd"
-        elif re.match(".*3", _date):
+        elif re.match(".*3$", _date):
             suffix = "rd"
 
         return(suffix)
